from cpp17_u8_char_literals import *

if cvar.a != "a":
    raise RuntimeError

if cvar.u != "u":
    raise RuntimeError

if cvar.u8 != "8":
    raise RuntimeError
